==> apache-samza-1.2.0-src.tgz: apache-samza-1.2.0-src/samza-sql/src/test/java/org/apache/samza/sql/util/MyTestPolyUdf.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.samza.sql.util;

import org.apache.samza.config.Config;
import org.apache.samza.sql.schema.SamzaSqlFieldType;
import org.apache.samza.sql.udfs.SamzaSqlUdf;
import org.apache.samza.sql.udfs.SamzaSqlUdfMethod;
import org.apache.samza.sql.udfs.ScalarUdf;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * UDF to test polymorphism.
 */
@SamzaSqlUdf(name = "MyTestPoly", description = "Test Polymorphism UDF.")
public class MyTestPolyUdf implements ScalarUdf {
  private static final Logger LOG = LoggerFactory.getLogger(MyTestPolyUdf.class);

  @SamzaSqlUdfMethod(params = SamzaSqlFieldType.INT32)
  public Integer execute(Integer value) {
    return value * 2;
  }

  @SamzaSqlUdfMethod(params = SamzaSqlFieldType.ANY)
  public Integer execute(String value) {
    return value.length() * 2;
  }


  @Override
  public void init(Config udfConfig) {
    LOG.info("Init called with {}", udfConfig);
  }
}

==> apache-samza-1.7.0-src.tgz: apache-samza-1.7.0-src/samza-sql/src/test/java/org/apache/samza/sql/util/MyTestPolyUdf.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.samza.sql.util;

import org.apache.samza.config.Config;
import org.apache.samza.context.Context;
import org.apache.samza.sql.schema.SamzaSqlFieldType;
import org.apache.samza.sql.udfs.SamzaSqlUdf;
import org.apache.samza.sql.udfs.SamzaSqlUdfMethod;
import org.apache.samza.sql.udfs.ScalarUdf;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * UDF to test polymorphism.
 */
@SamzaSqlUdf(name = "MyTestPoly", description = "Test Polymorphism UDF.")
public class MyTestPolyUdf implements ScalarUdf {
  private static final Logger LOG = LoggerFactory.getLogger(MyTestPolyUdf.class);

  @SamzaSqlUdfMethod(params = SamzaSqlFieldType.INT32)
  public Integer execute(Integer value) {
    return value * 2;
  }

  @SamzaSqlUdfMethod(params = SamzaSqlFieldType.STRING)
  public Integer execute(String value) {
    return value.length() * 2;
  }

  @Override
  public void init(Config udfConfig, Context context) {
    LOG.info("Init called with {}", udfConfig);
  }
}
